
# Slot: layers


Container of layers to be used to build the neural network.

URI: [https://w3id.org/neat/layerContainer__layers](https://w3id.org/neat/layerContainer__layers)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Layer](Layer.md)

## Parents


## Children


## Used by

 * [LayerContainer](LayerContainer.md)
